# ---------------------------------------------------------------------------
# Downloads.py
# Created on: 2013-10-27
#   David Tarboton
# Description:
#   This script automates the repetitive downloads of NLDAS data over a watershed
#   The toolbox location needs to be edited for your system
#   The file Downloads.csv needs to be edited to control the variables to download
# ---------------------------------------------------------------------------

# Import arcpy module
import arcpy, datetime, os
from arcpy import env

# Inputs -----------------------------------------------------------
gdbname="BaseLayers.gdb"   # geodatabase
zones=r"Layers\LoganBasin"  # Name of zone (basins) feature class in geodatabase
infile="Downloads.csv"
# End of inputs -----------------------------------------------------

# Load the LDAS toolbox.  Adjust this line to where it occurs in your system
arcpy.ImportToolbox("C:/Users/dtarb/Documents/ArcGIS/Packages/LDAStools/v101/LDAStools.tbx")

# Local variables:
# Use the current working directory as the folder
Folder=os.getcwd()  # or r"D:\Scratch\Ex5"
env.workspace = Folder

Basin = Folder+os.sep+gdbname+os.sep+zones

Outfold=Folder+os.sep+"NLDAS"
# If this folder does not exist make it
if not os.path.isdir(Outfold):
    os.makedirs(Outfold)

f=open(infile)
line=f.readline()  # reads the header
for line in f:
    print(line)
    cols=line.split(",")
    Outfolder=Outfold+os.sep+cols[0]
    if not os.path.isdir(Outfolder):
        os.makedirs(Outfolder)
    Dataset=cols[1]
    Var=cols[2]
    Begdate=cols[3]
    Enddate=cols[4]
    arcpy.LDASNOAHdownloader_LDASNOAHdownloader(Basin, Dataset,Var, Outfolder, Begdate, Enddate)

