# Python modules used
import arcpy, datetime, os, shutil
from arcpy import env
from arcpy.sa import *

# Inputs -----------------------------------------------------------
gdbname="BaseLayers.gdb"   # geodatabase
zones=r"Layers\LoganBasin"  # Name of zone (basins) feature class in geodatabase
mosaic = "Rainmosaic"   # Name of mosaiced layer in geodatabase that is to be zonally averaged
outtab = "Raintab"  # Name of table for zonal averaged data to be written in geodatabase.  The script will create this file
tempfolder="temp"     # name for temporary folder used for intermediate zone average tables
# End of inputs -----------------------------------------------------

arcpy.CheckOutExtension("spatial")   # Check out a spatial analyst license
Folder=os.getcwd() # Use the current working directory as the folder to work in
env.workspace = Folder

# Establish proper paths
zoneshape=gdbname + os.sep + zones  # Basin feature class
theMosaic=gdbname + os.sep + mosaic # The mosaiced layer that is being zonally averaged

# If temporary folder does not exist, create it
if not os.path.isdir(tempfolder):
    os.makedirs(tempfolder)
else:   # Write a message and exit
    print "A folder already exists at the location: " + tempfolder
    print "Delete or move this or use a different temporary folder location"
    quit()

dates=[]  # list to hold dates
vals=[]   # list to hold values
# Loop over all the mosaic values
with arcpy.da.UpdateCursor(theMosaic,["OBJECTID","Raster","YYYYMM"]) as cursor:
    for row in cursor:
        # Deduce date from the YYYYMM column and append it to our list
        dates=dates+[datetime.datetime.strptime(row[2],'%Y%m')]
        #   Create an output table for zonal statistics in the temporary folder
        zonetable=Folder + os.sep + tempfolder + os.sep + "t" + row[2]   # to keep unique name
        outZSaT = ZonalStatisticsAsTable(zoneshape,"OBJECTID",row[1],zonetable,"", "MEAN")
        tableRow = arcpy.UpdateCursor(zonetable)
        # zone table only has one row.  Extract its mean
        for linerow in tableRow:
            meanValue = linerow.MEAN
        vals=vals+[meanValue]  # Append the mean to our list
#  Clean up by removing unused objects to removes locks on the database
del linerow
del tableRow

# Write results to a table
tabnamefull=gdbname+os.sep+outtab
field1="Date"
field2="Value"
arcpy.CreateTable_management(gdbname, outtab,"","")   #  Create Table
arcpy.AddField_management(tabnamefull, field1,"DATE","","","","","")  #  Add date field
arcpy.AddField_management(tabnamefull, field2, "FLOAT","","","","","")  #  Add Value field
rows = arcpy.InsertCursor(tabnamefull,"")
for i in range(len(vals)):
    line = rows.newRow()
    line.setValue(field1,dates[i])
    line.setValue(field2,vals[i])
    rows.insertRow(line)
    print str(dates[i])+","+str(vals[i])

# Clean up
del line
del rows
try:
    if os.path.isdir(tempfolder):  # Remove temporary folder
        shutil.rmtree(tempfolder)
except:
    print "Unable to delete temporary folder: "+tempfolder
print "Done"
