# Python modules used
import sys
import arcpy, datetime, os, shutil
from arcpy import env
from arcpy.sa import *

# Inputs -----------------------------------------------------------
gdbname="BaseLayers.gdb"   # geodatabase
zones=r"Layers\LoganBasin"  # Name of zone (basins) feature class in geodatabase
outtable="zstats"
# End of inputs -----------------------------------------------------

# Check out the ArcGIS Spatial Analyst extension for using the zonal statistics function
arcpy.CheckOutExtension("spatial")

# Use the current working directory as the folder to work in
Folder=os.getcwd()  # or r"D:\Scratch\Ex5"
env.workspace = Folder

# Full file paths
zoneshape=gdbname + os.sep + zones  # Basin feature class
WorkFolder = Folder+os.sep+"NLDAS"  # This is the folder used for input data
TempFolder = Folder+os.sep+"temp"  # This is the folder where temporary tables are written
if not os.path.isdir(TempFolder):
    os.makedirs(TempFolder)
VarFolders=os.listdir(WorkFolder)
tabnamefull=gdbname+os.sep+outtable
field1="Varcode"
field2="Date"
field3="Value"
field4="TimeSupport"
arcpy.CreateTable_management(gdbname, outtable,"","")   #  Create Table
arcpy.AddField_management(tabnamefull, field1,"TEXT","","","","","")  #  Add code field
arcpy.AddField_management(tabnamefull, field2, "DATE","","","","","")  #  Add date field
arcpy.AddField_management(tabnamefull, field3,"FLOAT","","","","","")  #  Add value field
arcpy.AddField_management(tabnamefull, field4, "TEXT","","","","","")  #  Add support field
rows = arcpy.InsertCursor(tabnamefull,"")

for VarFolder in VarFolders:
    VarFiles=os.listdir(WorkFolder+os.sep+VarFolder)
    for theFile in VarFiles:
        if theFile.endswith(".asc"):  # Only ASC files
            if(theFile[-6:-4]=="00"):   # This occurs for an hourly file
                dateString = theFile[-15:-7]
                timeSupport="Hour"
            else:
                dateString = theFile[-10:-4]
                timeSupport="Month"
            #print VarFolder + " " + theFile + " " + dateString

            zonetable=TempFolder + os.sep +VarFolder+ dateString   # to keep unique name
            fullFile=WorkFolder+os.sep+VarFolder+os.sep+theFile
            outZSaT = ZonalStatisticsAsTable(zoneshape, "OBJECTID", fullFile,
                                      zonetable, "", "MEAN")
            tableRow = arcpy.UpdateCursor(zonetable)
        # zone table only has one row.  Extract its mean
            for linerow in tableRow:
                meanValue = linerow.MEAN
            print VarFolder + " " + dateString + " " + str(meanValue)
            line = rows.newRow()
            if timeSupport=="Hour":
                date=datetime.datetime.strptime(dateString,'%Y%m%d')
            else:
                date=datetime.datetime.strptime(dateString,'%Y%m')
            line.setValue(field1,VarFolder)
            line.setValue(field2,date)
            line.setValue(field3,meanValue)
            line.setValue(field4,timeSupport)
            rows.insertRow(line)
# Clean up
del line
del rows
del linerow
del tableRow
# redo last zonal statistics.  Append "t" to name to make it different.  This seems necessary to delete the locks
outZSaT = ZonalStatisticsAsTable(zoneshape, "OBJECTID", fullFile,
                                      zonetable+"t", "", "MEAN")
try:
    if os.path.isdir(TempFolder):  # Remove temporary folder
        shutil.rmtree(TempFolder)
except:
    print "Unable to delete temporary folder: "+TempFolder
print "Done"

